@@ -323,8 +323,8 @@ String.prototype.search = function(regexp){return 1;};
   * function slice(start, end) 
   * @type    String
   * @memberOf   String
-  * @param   {String} start
-  * @param   {String} end
+  * @param   {Number} start
+  * @param   {Number} end
   * @returns {String}
   * @throws  DOMException
   * @see     String
@@ -334,23 +334,23 @@ String.prototype.search = function(regexp){return 1;};
 String.prototype.slice = function(start, end){return "";};
  /**
   * function split(separator, limit) 
-  * @type    String
+  * @type    Array
   * @memberOf   String
   * @param   {String} separator
-  * @param   {String} limit
-  * @returns {String}
+  * @param   {Number} limit
+  * @returns {Array}
   * @throws  DOMException
   * @see     String
   * @since   Standard ECMA-262 3rd. Edition 
   * @since   Level 2 Document Object Model Core Definition.
  */  
-String.prototype.split = function(separator, limit){return "";};
+String.prototype.split = function(separator, limit){return [];};
  /**
   * function substring(start, end) 
   * @type    String
   * @memberOf   String
-  * @param   {String} start
-  * @param   {String} end
+  * @param   {Number} start
+  * @param   {Number} end
   * @returns {String}
   * @throws  DOMException
   * @see     String
@@ -1297,8 +1297,8 @@ Global.prototype.parseInt=function(s,radix){};
   * function parseFloat(s)
   * @memberOf Global
   * @param {String} s
-  * @type Object
-  * @returns {Object}
+  * @type Number
+  * @returns {Number}
   * @since   Standard ECMA-262 3rd. Edition 
   * @since   Level 2 Document Object Model Core Definition.
   * @see    http://www.w3.org/TR/2000/REC-DOM-Level-2-Core-20001113/ecma-script-binding.html     
